Learn R Programming

dglars (version 1.0.2)

coef.cvdglars: Extract the coefficients estimated by cvdglars

Description

coef.cvdglars is used to extract the coefficients estimated by the $k$-fold cross-validation deviance.

Usage

## S3 method for class 'cvdglars':
coef(object, ...)

Arguments

object
fitted cvdglars object
...
additional arguments

Value

  • coef.cvdglars returns a vector with the coefficients estimated by the $k$-fold cross-validation deviance.

See Also

cvdglars function.

Examples

Run this code
###########################
# Logistic regression model

set.seed(123)

n <- 100
p <- 10
X <- matrix(rnorm(n*p), n, p)
b <- 1:2
eta <- b[1] + X[,1] * b[2]
mu <- binomial()$linkinv(eta)
y <- rbinom(n, 1, mu)
fit <- cvdglars.fit(X, y, family = "binomial")
coef(fit)

Run the code above in your browser using DataLab